package WebGUI::i18n::Dutch::Asset_GalleryAlbum;
use utf8;
our $I18N = {
  'Adding %s to album' => {
    'lastUpdated' => '1254902356',
    'message' => '%s toevoegen aan album'
  },
  'Extracting archive' => {
    'lastUpdated' => '1254902367',
    'message' => 'Archief uitpakken'
  },
  'Found file: %s' => {
    'lastUpdated' => '1254902377',
    'message' => 'Bestand gevonden: %s'
  },
  'Getting list of files for sorting purposes' => {
    'lastUpdated' => '1285166661',
    'message' => 'Lijst maken van bestanden om te kunnen sorteren.'
  },
  'Requesting commit for version tag' => {
    'lastUpdated' => '1254902399',
    'message' => 'Verzoek voor doorvoeren versie tag'
  },
  'Uploading archive' => {
    'lastUpdated' => '1254902408',
    'message' => 'Archief uploaden'
  },
  'add photo' => {
    'lastUpdated' => '1242726582',
    'message' => 'Voeg een foto toe'
  },
  'addArchive error generic' => {
    'lastUpdated' => '1218985888',
    'message' => 'Er is een fout opgetreden bij het uploaden van het archief: %s'
  },
  'addArchive error too big' => {
    'lastUpdated' => '1201264681',
    'message' => 'Het archief wat u probeert te uploaden is te groot. Probeer het alstublieft nog een keer.'
  },
  'addArchive file' => {
    'lastUpdated' => '1204031040',
    'message' => 'Archiveer'
  },
  'addArchive friendsOnly' => {
    'lastUpdated' => '1204031049',
    'message' => 'Alleen vrienden'
  },
  'addArchive keywords' => {
    'lastUpdated' => '1204031057',
    'message' => 'Labels'
  },
  'addArchive location' => {
    'lastUpdated' => '1275486898',
    'message' => 'Lokatie'
  },
  'addArchive message' => {
    'lastUpdated' => '1201264649',
    'message' => 'De bestanden zijn verstuurd voor goedkeuring en plaatsing. <a href="%s">Ga terug naar het album</a>.'
  },
  'addArchive sortBy' => {
    'lastUpdated' => '1275486905',
    'message' => 'Sorteer op'
  },
  'addArchive sortBy date' => {
    'lastUpdated' => '1275486912',
    'message' => 'Datum'
  },
  'addArchive sortBy fileOrder' => {
    'lastUpdated' => '1275486925',
    'message' => 'Bestandsvolgorde'
  },
  'addArchive sortBy name' => {
    'lastUpdated' => '1275486930',
    'message' => 'Naam'
  },
  'assetName' => {
    'lastUpdated' => '1201264519',
    'message' => 'Galerie album'
  },
  'cancel' => {
    'lastUpdated' => '1201264451',
    'message' => 'Annuleren'
  },
  'delete message' => {
    'lastUpdated' => '1201264505',
    'message' => 'Het album is verwijderd. <a href="%s">Keer terug naar de galerie</a>.'
  },
  'editForm assetIdThumbnail label' => {
    'lastUpdated' => '1204031084',
    'message' => 'Kies een miniatuur als representatie voor het album.'
  },
  'editForm description label' => {
    'lastUpdated' => '1204031096',
    'message' => 'Beschrijving'
  },
  'editForm othersCanAdd label' => {
    'lastUpdated' => '1218182606',
    'message' => 'Anderen kunnen toevoegen'
  },
  'editForm title label' => {
    'lastUpdated' => '1204031105',
    'message' => 'Titel'
  },
  'help addArchive body' => {
    'lastUpdated' => '1201264717',
    'message' => 'Deze variabelen zijn beschikbaar voor het archief toevoegen uiterlijk van het album'
  },
  'help addArchive title' => {
    'lastUpdated' => '1201264746',
    'message' => 'Galerie album archief toevoeg variabelen'
  },
  'help common body' => {
    'lastUpdated' => '1201264776',
    'message' => 'Deze variabelen zijn beschikbaar voor alle uiterlijken van album assets.'
  },
  'help common title' => {
    'lastUpdated' => '1201264802',
    'message' => 'Galerie album variabelen (Normaal)'
  },
  'help delete body' => {
    'lastUpdated' => '1201264892',
    'message' => 'Deze variabelen zijn beschikbaar voor het verwijderen uiterlijk van het album.'
  },
  'help delete title' => {
    'lastUpdated' => '1201264917',
    'message' => 'Galerie album verwijder variabelen'
  },
  'help edit body' => {
    'lastUpdated' => '1201264974',
    'message' => 'De variabelen zijn beschikbaar voor het bewerk uiterlijk van het album.'
  },
  'help edit title' => {
    'lastUpdated' => '1201264963',
    'message' => 'Galerie album bewerk variabelen'
  },
  'help fileLoop body' => {
    'lastUpdated' => '1201265057',
    'message' => 'Deze variabelen zijn standaard beschikbaar voor alle uiterlijken die een loop over bestanden doorlopen.'
  },
  'help fileLoop title' => {
    'lastUpdated' => '1201265044',
    'message' => 'Galerie album bestand loop variabelen'
  },
  'help slideshow body' => {
    'lastUpdated' => '1201265098',
    'message' => 'Deze variabelen zijn beschikbaar voor het diavoorstelling uiterlijk van het album.'
  },
  'help slideshow title' => {
    'lastUpdated' => '1201265141',
    'message' => 'Galerie album diavoorstelling variabelen'
  },
  'help thumbnails body' => {
    'lastUpdated' => '1201266042',
    'message' => 'Deze variabelen zijn beschikbaar voor het miniatuur uiterlijk van het album.'
  },
  'help thumbnails title' => {
    'lastUpdated' => '1201265787',
    'message' => 'Galerie album miniatuur variabelen'
  },
  'help view body' => {
    'lastUpdated' => '1201266141',
    'message' => 'Deze variabelen zijn voor het album uiterlijk van album assets.'
  },
  'help view title' => {
    'lastUpdated' => '1201266181',
    'message' => 'Galerie album uiterlijk variabelen'
  },
  'help viewRss body' => {
    'lastUpdated' => '1201266594',
    'message' => 'Deze variabelen zijn beschikbaar voor de RSS feed van het album.'
  },
  'help viewRss title' => {
    'lastUpdated' => '1201266615',
    'message' => 'Galerie album RSS feeds variabelen'
  },
  'helpvar canAddFile' => {
    'lastUpdated' => '1201266666',
    'message' => 'Deze variabele heeft de waarde &quot;waar&quot; als de gebruiker bestanden aan dit album toe kan voegen.'
  },
  'helpvar canEdit' => {
    'lastUpdated' => '1201266701',
    'message' => 'Deze variabele heeft de waarde &quot;waar&quot; als de gebruiker dit album kan bewerken.'
  },
  'helpvar error' => {
    'lastUpdated' => '1221211214',
    'message' => 'Een foutmelding die aan de gebruiker getoond wordt. Alleen gedefini&euml;erd als er iets fout is gegaan.'
  },
  'helpvar fileCount' => {
    'lastUpdated' => '1201266819',
    'message' => 'Het aantal bestanden in dit album'
  },
  'helpvar file_' => {
    'lastUpdated' => '1201266895',
    'message' => 'Het bestand dat momenteel getoond wordt op de miniaturen pagina. Alle normale variabelen voor dit bestand zijn beschikbaar door er &quot;file_&quot; ervoor te zetten'
  },
  'helpvar file_*' => {
    'lastUpdated' => '1242137749',
    'message' => 'Het huidige bestand dat wordt bekeken in de thumbnails pagina. Alle variabelen voor dit bestand zijn beschikbaar door "file_" voor de namen van de variabelen te zetten.'
  },
  'helpvar file_loop' => {
    'lastUpdated' => '1201266799',
    'message' => 'De loop van bestanden op deze pagina.'
  },
  'helpvar file_loop edit' => {
    'lastUpdated' => '1201266958',
    'message' => 'Dit is een loop over de bestanden die tegelijkertijd bewerkt kunnen worden in het Bewerk album scherm.'
  },
  'helpvar file_loop viewRss' => {
    'lastUpdated' => '1201267005',
    'message' => 'Dit is de loop over de bestanden die voor RSS feeds worden gebruikt en extra variabelen bevatten.'
  },
  'helpvar form_archive' => {
    'lastUpdated' => '1201267045',
    'message' => 'Het archief voor upload. Een WebGUI::Form::File controleermiddel.'
  },
  'helpvar form_cancel' => {
    'lastUpdated' => '1201267062',
    'message' => 'Annuleer het formulier'
  },
  'helpvar form_delete' => {
    'lastUpdated' => '1213630807',
    'message' => 'Een knop om de afbeelding te verwijderen'
  },
  'helpvar form_demote' => {
    'lastUpdated' => '1213702521',
    'message' => 'Een knop om de ranking van de afbeelding te verlagen. Dit wordt gebruikt om de volgorde van de fotos te veranderen.'
  },
  'helpvar form_description' => {
    'lastUpdated' => '1201267081',
    'message' => 'De omschrijving van het album'
  },
  'helpvar form_end' => {
    'lastUpdated' => '1201267096',
    'message' => 'Het einde van het formulier'
  },
  'helpvar form_friendsOnly' => {
    'lastUpdated' => '1201267121',
    'message' => 'Moet dit bestand alleen voor vrienden zijn?'
  },
  'helpvar form_keywords' => {
    'lastUpdated' => '1201267146',
    'message' => 'De trefwoorden van de bestanden die ge-upload worden.'
  },
  'helpvar form_location' => {
    'lastUpdated' => '1275486946',
    'message' => 'De lokatie van de bestanden.'
  },
  'helpvar form_promote' => {
    'lastUpdated' => '1213702560',
    'message' => 'Een knop om een afbeelding te laten stijgen in ranking. Dit wordt gebruikt om de volgorde van de fotos te veranderen.'
  },
  'helpvar form_rotateLeft' => {
    'lastUpdated' => '1271835103',
    'message' => 'Een knop om de foto 90 graden tegen de klok in te draaien.'
  },
  'helpvar form_rotateRight' => {
    'lastUpdated' => '1271835090',
    'message' => 'Een knop om de foto 90 graden met de klok mee te draaien.'
  },
  'helpvar form_sortBy' => {
    'lastUpdated' => '1275486967',
    'message' => 'De eigenschap waar foto\'s op gesorteerd moeten worden.'
  },
  'helpvar form_start' => {
    'lastUpdated' => '1201267360',
    'message' => 'Het begin van het formulier'
  },
  'helpvar form_submit' => {
    'lastUpdated' => '1201268311',
    'message' => 'Verstuur het formulier'
  },
  'helpvar form_synopsis' => {
    'lastUpdated' => '1213702590',
    'message' => 'Eeen HTML gebied voor de miniatuur van de afbeelding'
  },
  'helpvar form_title' => {
    'lastUpdated' => '1201268327',
    'message' => 'De titel van het album'
  },
  'helpvar gallery_displayTitle' => {
    'lastUpdated' => '1238424452',
    'message' => 'Of het album dat dit bestand bevat ingesteld is om zijn titel te tonen, of niet.'
  },
  'helpvar gallery_menuTitle' => {
    'lastUpdated' => '1213702615',
    'message' => 'De menu titel van de galerie die dit bestand bevat.'
  },
  'helpvar gallery_title' => {
    'lastUpdated' => '1213702631',
    'message' => 'De titel van de galerie die dit bestand bevat.'
  },
  'helpvar gallery_url' => {
    'lastUpdated' => '1213702648',
    'message' => 'Het URL van de galerie die dit bestand bevat.'
  },
  'helpvar isAlbumThumbnail' => {
    'lastUpdated' => '1201268512',
    'message' => 'Dit is waar als het bestand de miniatuur van het huidige album.'
  },
  'helpvar isNewAlbum' => {
    'lastUpdated' => '1204031143',
    'message' => 'Deze variabele is waar wanneer de gebruiker een nieuw album aan de galerie toevoegt.'
  },
  'helpvar isPending' => {
    'lastUpdated' => '1213702728',
    'message' => 'Een indicator die laat zien of het galerie album nog niet is goedgekeurd. Gebruikers die dit album kunnen bewerken mogen dit album zien voordat het wordt goedgekeurd.'
  },
  'helpvar nextAlbum_thumbnailUrl' => {
    'lastUpdated' => '1213973039',
    'message' => 'Het URL naar de miniatuur afbeelding van het volgende album in de lijst.'
  },
  'helpvar nextAlbum_title' => {
    'lastUpdated' => '1213973317',
    'message' => 'De titel van het volgende album in de lijst.'
  },
  'helpvar nextAlbum_url' => {
    'lastUpdated' => '1213973479',
    'message' => 'Het URL naar het volgende album in de lijst, de volgorde van de Galerie album lijst wordt aangehouden. Als er geen volgend album is, zal deze variabele niet bestaan.'
  },
  'helpvar ownerUsername' => {
    'lastUpdated' => '1201268545',
    'message' => 'De gebruikersnaam van de eigenaar van dit album.'
  },
  'helpvar previousAlbum_thumbnailUrl' => {
    'lastUpdated' => '1213973055',
    'message' => 'Het URL naar de miniatuur afbeelding van het vorige album in de lijst.<br /> '
  },
  'helpvar previousAlbum_title' => {
    'lastUpdated' => '1213973329',
    'message' => 'De titel van het vorige album in de lijst.<br /> '
  },
  'helpvar previousAlbum_url' => {
    'lastUpdated' => '1213973500',
    'message' => 'Het URL naar het vorige album in de lijst, de volgorde van de Galerie album lijst wordt aangehouden. Als er geen vorig album is, zal deze variabele niet bestaan.<br /> '
  },
  'helpvar rssDate' => {
    'lastUpdated' => '1201268790',
    'message' => 'De RFC2822-overeenkomstige datum van de RSS feed.'
  },
  'helpvar thumbnailUrl' => {
    'lastUpdated' => '1201268866',
    'message' => 'Het URL naar het miniatuur van het bestand dat als het miniatuur voor het album is ingesteld.'
  },
  'helpvar url_addArchive' => {
    'lastUpdated' => '1201269388',
    'message' => 'Het URL voor het toevoegen van een bestandsarchief aan het album.'
  },
  'helpvar url_addNoClass' => {
    'lastUpdated' => '1201269327',
    'message' => 'Het URL waar iets aan het album kan worden toegevoegd. Aan het einde moet &quot;;class=Class::Name&quot; worden toegevoegd.'
  },
  'helpvar url_addPhoto' => {
    'lastUpdated' => '1201269270',
    'message' => 'Het URL waar een foto aan het album toegevoegd kan worden.'
  },
  'helpvar url_delete' => {
    'lastUpdated' => '1201269242',
    'message' => 'Het URL waar dit album verwijderd kan worden.'
  },
  'helpvar url_edit' => {
    'lastUpdated' => '1201269210',
    'message' => 'Het URL waar dit album bewerkt kan worden'
  },
  'helpvar url_listAlbums' => {
    'lastUpdated' => '1201269154',
    'message' => 'Het URL naar het lijst van albums uiterlijk van de bovenliggende galerie.'
  },
  'helpvar url_listAlbumsRss' => {
    'lastUpdated' => '1201775983',
    'message' => 'De URL naar het RSS-bestand met de albums van de bovenliggende galerie.'
  },
  'helpvar url_listFilesForCurrentUser' => {
    'lastUpdated' => '1201268229',
    'message' => 'Het URL waar bestanden in een lijst gezet worden voor de huidige gebruiker, dit is een onderdeel van de bovenliggende galerie.'
  },
  'helpvar url_listFilesForOwner' => {
    'lastUpdated' => '1201267192',
    'message' => 'Het URL naar het listFilesForUser scherm voor de eigenaar van dit album'
  },
  'helpvar url_search' => {
    'lastUpdated' => '1201266563',
    'message' => 'Het URL naar het zoek uiterlijk van de bovenliggende galerie'
  },
  'helpvar url_slideshow' => {
    'lastUpdated' => '1201266345',
    'message' => 'Het URL naar het diavoorstelling uiterlijk van dit album.'
  },
  'helpvar url_thumbnails' => {
    'lastUpdated' => '1201266314',
    'message' => 'Het URL naar de minatuur uitvoering van dit album.'
  },
  'helpvar url_viewRss' => {
    'lastUpdated' => '1201266287',
    'message' => 'Het URL naar de RSS feed van dit album.'
  },
  'helpvar url_yes' => {
    'lastUpdated' => '1202912447',
    'message' => 'Bevestig het verwijderen van het album.'
  },
  'return to album' => {
    'lastUpdated' => '1242726618',
    'message' => 'Terug naar fotoalbum'
  },
  'rotate left' => {
    'lastUpdated' => '1271835044',
    'message' => '90° linksom'
  },
  'rotate right' => {
    'lastUpdated' => '1271835053',
    'message' => '90° rechtsom'
  },
  'save' => {
    'lastUpdated' => '1201266201',
    'message' => 'Opslaan'
  },
  'save message' => {
    'lastUpdated' => '1201266266',
    'message' => 'De instellingen van het album zijn opgeslagen. <a href="%s">Ga terug naar het album</a>.'
  },
  'template add' => {
    'lastUpdated' => '1231707700',
    'message' => 'Album toevoegen'
  },
  'template addArchive body' => {
    'lastUpdated' => '1204031194',
    'message' => 'Dit formulier accepteert zip en tar/gzipped archieven.'
  },
  'template addArchive title' => {
    'lastUpdated' => '1204031209',
    'message' => 'Voeg zip archief toe'
  },
  'template album thumbnail alt' => {
    'lastUpdated' => '1238424325',
    'message' => 'Bekijk thumbnail voor'
  },
  'template assetName' => {
    'lastUpdated' => '1204031216',
    'message' => 'Album'
  },
  'template delete message' => {
    'lastUpdated' => '1238424267',
    'message' => 'Weet je zeker dat je dit album wilt verwijderen?'
  },
  'template delete no' => {
    'lastUpdated' => '1206953182',
    'message' => 'Nee'
  },
  'template delete yes' => {
    'lastUpdated' => '1206953188',
    'message' => 'Ja'
  },
  'template edit' => {
    'lastUpdated' => '1231707714',
    'message' => 'Bewerk album'
  },
  'template file creationDate' => {
    'lastUpdated' => '1203437459',
    'message' => 'Geupload op'
  },
  'template file numberOfComments' => {
    'lastUpdated' => '1203437453',
    'message' => 'Commentaar'
  },
  'template upload archive' => {
    'lastUpdated' => '1204031232',
    'message' => 'Zip archief'
  },
  'template upload single' => {
    'lastUpdated' => '1204031247',
    'message' => 'Enkel bestand'
  },
  'template upload type' => {
    'lastUpdated' => '1204031266',
    'message' => 'Upload type'
  },
  'template url' => {
    'lastUpdated' => '1203437448',
    'message' => 'Album'
  },
  'template url_addDescription' => {
    'lastUpdated' => '1242137773',
    'message' => 'Voeg een beschrijving toe'
  },
  'template url_addPhoto' => {
    'lastUpdated' => '1203437466',
    'message' => 'Foto toevoegen'
  },
  'template url_delete' => {
    'lastUpdated' => '1203437472',
    'message' => 'Verwijder album'
  },
  'template url_edit' => {
    'lastUpdated' => '1203437478',
    'message' => 'Bewerk album'
  },
  'template url_slideshow' => {
    'lastUpdated' => '1203437483',
    'message' => 'Slideshow'
  },
  'template url_thumbnails' => {
    'lastUpdated' => '1203516797',
    'message' => 'Miniaturen'
  },
  'template use as thumbnail' => {
    'lastUpdated' => '1271834969',
    'message' => 'Gebruik als album representatie'
  },
  'what next' => {
    'lastUpdated' => '1213702753',
    'message' => 'Hoe verder?'
  }
}
;

1;
